#[non_exhaustive]pub enum RangeType {
Ecosystem,
Git,
Semver,
Unspecified,
}Expand description
Type of the affected range supplied. This can be an ecosystem specific value, semver, or a git commit hash.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Ecosystem
The versions introduced and fixed are arbitrary, uninterpreted strings specific to the package ecosystem
Git
The versions introduced and fixed are full-length Git commit hashes.
Semver
The versions introduced and fixed are semantic versions as defined by SemVer 2.0.0.
Unspecified
Default for the case where a range type is omitted.